"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.model_api import ModelApi  # noqa: E501


class TestModelApi(unittest.TestCase):
    """ModelApi unit test stubs"""

    def setUp(self):
        self.api = ModelApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_model_errors(self):
        """Test case for add_model_errors

        Add errors to model  # noqa: E501
        """
        pass

    def test_bulk_delete_model_classifications(self):
        """Test case for bulk_delete_model_classifications

        Remove all classifications from model's elements  # noqa: E501
        """
        pass

    def test_bulk_delete_model_properties(self):
        """Test case for bulk_delete_model_properties

        Delete many Property of a model  # noqa: E501
        """
        pass

    def test_bulk_delete_model_property_definitions(self):
        """Test case for bulk_delete_model_property_definitions

        Delete many PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_bulk_delete_model_units(self):
        """Test case for bulk_delete_model_units

        Delete many Units of a model  # noqa: E501
        """
        pass

    def test_bulk_delete_property_set(self):
        """Test case for bulk_delete_property_set

        Delete many PropertySet of a model  # noqa: E501
        """
        pass

    def test_bulk_full_update_elements(self):
        """Test case for bulk_full_update_elements

        Update many elements at once (only changing fields may be defined)  # noqa: E501
        """
        pass

    def test_bulk_full_update_model_property(self):
        """Test case for bulk_full_update_model_property

        Update some fields of many properties of a model  # noqa: E501
        """
        pass

    def test_bulk_remove_classifications_of_element(self):
        """Test case for bulk_remove_classifications_of_element

        Remove many classifications from an element  # noqa: E501
        """
        pass

    def test_bulk_remove_documents_of_element(self):
        """Test case for bulk_remove_documents_of_element

        Remove many documents from an element  # noqa: E501
        """
        pass

    def test_bulk_remove_elements_from_classification(self):
        """Test case for bulk_remove_elements_from_classification

        Remove the classifications from all elements  # noqa: E501
        """
        pass

    def test_bulk_update_elements(self):
        """Test case for bulk_update_elements

        Update many elements at once (all field must be defined)  # noqa: E501
        """
        pass

    def test_bulk_update_model_property(self):
        """Test case for bulk_update_model_property

        Update all fields of many properties of a model  # noqa: E501
        """
        pass

    def test_create_access_token(self):
        """Test case for create_access_token

        Create a token for this model  # noqa: E501
        """
        pass

    def test_create_building(self):
        """Test case for create_building

        Create a building of a model  # noqa: E501
        """
        pass

    def test_create_building_plan(self):
        """Test case for create_building_plan

        Create a relation between a 2d model and a building  # noqa: E501
        """
        pass

    def test_create_classification_element_relations(self):
        """Test case for create_classification_element_relations

        Create association between existing classification and existing element  # noqa: E501
        """
        pass

    def test_create_classifications_of_element(self):
        """Test case for create_classifications_of_element

        Create one or many classifications to an element  # noqa: E501
        """
        pass

    def test_create_element(self):
        """Test case for create_element

        Create an element in the model  # noqa: E501
        """
        pass

    def test_create_element_property_set(self):
        """Test case for create_element_property_set

        Create a PropertySets to an element  # noqa: E501
        """
        pass

    def test_create_element_property_set_property(self):
        """Test case for create_element_property_set_property

        Create a property to a PropertySet  # noqa: E501
        """
        pass

    def test_create_element_property_set_property_definition(self):
        """Test case for create_element_property_set_property_definition

        Create a Definition to a Property  # noqa: E501
        """
        pass

    def test_create_element_property_set_property_definition_unit(self):
        """Test case for create_element_property_set_property_definition_unit

        Create a Unit to a Definition  # noqa: E501
        """
        pass

    def test_create_layer(self):
        """Test case for create_layer

        Create a layer in the model  # noqa: E501
        """
        pass

    def test_create_meta_building(self):
        """Test case for create_meta_building

        Create an empty 3D Model  # noqa: E501
        """
        pass

    def test_create_model(self):
        """Test case for create_model

        Make a PDF or Image file a Model  # noqa: E501
        """
        pass

    def test_create_model_property_definition(self):
        """Test case for create_model_property_definition

        Create a PropertyDefinition on the model  # noqa: E501
        """
        pass

    def test_create_model_unit(self):
        """Test case for create_model_unit

        Create a Unit on a model  # noqa: E501
        """
        pass

    def test_create_property_set(self):
        """Test case for create_property_set

        Create one or many PropertySet  # noqa: E501
        """
        pass

    def test_create_property_set_element_relations(self):
        """Test case for create_property_set_element_relations

        Create association between PropertySet and element  # noqa: E501
        """
        pass

    def test_create_raw_elements(self):
        """Test case for create_raw_elements

        Create elements in an optimized format  # noqa: E501
        """
        pass

    def test_create_space(self):
        """Test case for create_space

        Create a space in the model  # noqa: E501
        """
        pass

    def test_create_storey(self):
        """Test case for create_storey

        Create a storey of a model  # noqa: E501
        """
        pass

    def test_create_storey_plan(self):
        """Test case for create_storey_plan

        Create a relation between a 2d model and a storey  # noqa: E501
        """
        pass

    def test_create_system(self):
        """Test case for create_system

        Create a system in the model  # noqa: E501
        """
        pass

    def test_create_tileset(self):
        """Test case for create_tileset

        Create the tileset of the model and upload all files  # noqa: E501
        """
        pass

    def test_create_zone(self):
        """Test case for create_zone

        Create a zone in the model  # noqa: E501
        """
        pass

    def test_create_zone_space(self):
        """Test case for create_zone_space

        Create a space in a zone  # noqa: E501
        """
        pass

    def test_delete_access_token(self):
        """Test case for delete_access_token

        Delete a token  # noqa: E501
        """
        pass

    def test_delete_building(self):
        """Test case for delete_building

        Delete a building of a model  # noqa: E501
        """
        pass

    def test_delete_building_plan(self):
        """Test case for delete_building_plan

        Delete the relation between a 2d model and a building  # noqa: E501
        """
        pass

    def test_delete_element(self):
        """Test case for delete_element

        Delete an element of a model  # noqa: E501
        """
        pass

    def test_delete_layer(self):
        """Test case for delete_layer

        Delete a layer of a model  # noqa: E501
        """
        pass

    def test_delete_model(self):
        """Test case for delete_model

        Delete a model  # noqa: E501
        """
        pass

    def test_delete_model_property(self):
        """Test case for delete_model_property

        Delete a Property of a model  # noqa: E501
        """
        pass

    def test_delete_model_property_definition(self):
        """Test case for delete_model_property_definition

        Delete a PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_delete_model_unit(self):
        """Test case for delete_model_unit

        Delete a Unit of a model  # noqa: E501
        """
        pass

    def test_delete_model_without_doc(self):
        """Test case for delete_model_without_doc

        Delete the Model without deleting the related document  # noqa: E501
        """
        pass

    def test_delete_property_set(self):
        """Test case for delete_property_set

        Delete a PropertySet of a model  # noqa: E501
        """
        pass

    def test_delete_space(self):
        """Test case for delete_space

        Delete a space  # noqa: E501
        """
        pass

    def test_delete_storey(self):
        """Test case for delete_storey

        Delete a storey of a model  # noqa: E501
        """
        pass

    def test_delete_storey_plan(self):
        """Test case for delete_storey_plan

        Delete the relation between a 2d model and a storey  # noqa: E501
        """
        pass

    def test_delete_system(self):
        """Test case for delete_system

        Delete a system of a model  # noqa: E501
        """
        pass

    def test_delete_zone(self):
        """Test case for delete_zone

        Delete a zone of a model  # noqa: E501
        """
        pass

    def test_delete_zone_space(self):
        """Test case for delete_zone_space

        Delete a space of a zone  # noqa: E501
        """
        pass

    def test_export_ifc(self):
        """Test case for export_ifc

        Export IFC  # noqa: E501
        """
        pass

    def test_full_update_element(self):
        """Test case for full_update_element

        Update all fields of an element  # noqa: E501
        """
        pass

    def test_get_access_token(self):
        """Test case for get_access_token

        Retrieve one token created for this model  # noqa: E501
        """
        pass

    def test_get_access_tokens(self):
        """Test case for get_access_tokens

        Retrieve all tokens created for this model  # noqa: E501
        """
        pass

    def test_get_building(self):
        """Test case for get_building

        Retrieve a building of a model  # noqa: E501
        """
        pass

    def test_get_building_plan_positioning(self):
        """Test case for get_building_plan_positioning

        Retrieve the postioning of the plan in the building  # noqa: E501
        """
        pass

    def test_get_buildings(self):
        """Test case for get_buildings

        Retrieve all buildings of a model  # noqa: E501
        """
        pass

    def test_get_classifications_of_element(self):
        """Test case for get_classifications_of_element

        Retrieve all classifications of an element  # noqa: E501
        """
        pass

    def test_get_documents_of_element(self):
        """Test case for get_documents_of_element

        Retrieve all documents of an element  # noqa: E501
        """
        pass

    def test_get_element(self):
        """Test case for get_element

        Retrieve an element of a model  # noqa: E501
        """
        pass

    def test_get_element_linked_documents(self):
        """Test case for get_element_linked_documents

        Retrieve all documents linked to any element  # noqa: E501
        """
        pass

    def test_get_element_property_set(self):
        """Test case for get_element_property_set

        Retrieve a PropertySet of an element  # noqa: E501
        """
        pass

    def test_get_element_property_set_properties(self):
        """Test case for get_element_property_set_properties

        Retrieve all Properties of a PropertySet  # noqa: E501
        """
        pass

    def test_get_element_property_set_property(self):
        """Test case for get_element_property_set_property

        Retrieve a Property of a PropertySet  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definition(self):
        """Test case for get_element_property_set_property_definition

        Retrieve a Definition of a Property  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definition_unit(self):
        """Test case for get_element_property_set_property_definition_unit

        Retrieve a Unit of a Definition  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definition_units(self):
        """Test case for get_element_property_set_property_definition_units

        Retrieve all Units of a Definition  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definitions(self):
        """Test case for get_element_property_set_property_definitions

        Retrieve all Definitions of a PropertySet  # noqa: E501
        """
        pass

    def test_get_element_property_sets(self):
        """Test case for get_element_property_sets

        Retrieve all PropertySets of an element  # noqa: E501
        """
        pass

    def test_get_elements(self):
        """Test case for get_elements

        Retrieve all elements of a model  # noqa: E501
        """
        pass

    def test_get_elements_from_classification(self):
        """Test case for get_elements_from_classification

        Retrieve all elements with the classification  # noqa: E501
        """
        pass

    def test_get_layer(self):
        """Test case for get_layer

        Retrieve a layer of a model  # noqa: E501
        """
        pass

    def test_get_layers(self):
        """Test case for get_layers

        Retrieve all layers of a model  # noqa: E501
        """
        pass

    def test_get_material(self):
        """Test case for get_material

        Retrieve a material of a model  # noqa: E501
        """
        pass

    def test_get_materials(self):
        """Test case for get_materials

        Retrieve all materials of a model  # noqa: E501
        """
        pass

    def test_get_model(self):
        """Test case for get_model

        Retrieve one model  # noqa: E501
        """
        pass

    def test_get_model_classifications(self):
        """Test case for get_model_classifications

        Retrieve all classifications in a model  # noqa: E501
        """
        pass

    def test_get_model_material(self):
        """Test case for get_model_material

        Retrieve a material of a model  # noqa: E501
        """
        pass

    def test_get_model_materials(self):
        """Test case for get_model_materials

        Retrieve all materials of a model  # noqa: E501
        """
        pass

    def test_get_model_properties(self):
        """Test case for get_model_properties

        Retrieve all Properties of a model  # noqa: E501
        """
        pass

    def test_get_model_property(self):
        """Test case for get_model_property

        Retrieve a Property of a model  # noqa: E501
        """
        pass

    def test_get_model_property_definition(self):
        """Test case for get_model_property_definition

        Retrieve a PropertyDefinition of a model  # noqa: E501
        """
        pass

    def test_get_model_property_definitions(self):
        """Test case for get_model_property_definitions

        Retrieve all PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_get_model_unit(self):
        """Test case for get_model_unit

        Retrieve a Unit of a model  # noqa: E501
        """
        pass

    def test_get_model_units(self):
        """Test case for get_model_units

        Retrieve all Units of a model  # noqa: E501
        """
        pass

    def test_get_models(self):
        """Test case for get_models

        Retrieve all models  # noqa: E501
        """
        pass

    def test_get_processor_handler(self):
        """Test case for get_processor_handler

        Retrieve a processor handler  # noqa: E501
        """
        pass

    def test_get_processor_handlers(self):
        """Test case for get_processor_handlers

        Get all processor handlers  # noqa: E501
        """
        pass

    def test_get_property_set(self):
        """Test case for get_property_set

        Retrieve a PropertySet of a model  # noqa: E501
        """
        pass

    def test_get_property_sets(self):
        """Test case for get_property_sets

        Retrieve all PropertySets of a model  # noqa: E501
        """
        pass

    def test_get_raw_elements(self):
        """Test case for get_raw_elements

        Retrieve all elements in a optimized format  # noqa: E501
        """
        pass

    def test_get_simple_element(self):
        """Test case for get_simple_element

        Retrieve an element of a model with a simple value representation  # noqa: E501
        """
        pass

    def test_get_simple_elements(self):
        """Test case for get_simple_elements

        Retrieve all elements of a model with a simple value representation  # noqa: E501
        """
        pass

    def test_get_space(self):
        """Test case for get_space

        Retrieve one space of the model  # noqa: E501
        """
        pass

    def test_get_spaces(self):
        """Test case for get_spaces

        Retrieve all spaces of the model  # noqa: E501
        """
        pass

    def test_get_storey(self):
        """Test case for get_storey

        Retrieve a storey of a model  # noqa: E501
        """
        pass

    def test_get_storey_plan_positioning(self):
        """Test case for get_storey_plan_positioning

        Retrieve the postioning of the plan in the storey  # noqa: E501
        """
        pass

    def test_get_storeys(self):
        """Test case for get_storeys

        Retrieve all storeys of a model  # noqa: E501
        """
        pass

    def test_get_system(self):
        """Test case for get_system

        Retrieve a system of a model  # noqa: E501
        """
        pass

    def test_get_systems(self):
        """Test case for get_systems

        Retrieve all systems of a model  # noqa: E501
        """
        pass

    def test_get_tileset(self):
        """Test case for get_tileset

        Retrieve the tileset of the model  # noqa: E501
        """
        pass

    def test_get_zone(self):
        """Test case for get_zone

        Retrieve one zone of a model  # noqa: E501
        """
        pass

    def test_get_zone_space(self):
        """Test case for get_zone_space

        Retrieve one space of a zone  # noqa: E501
        """
        pass

    def test_get_zone_spaces(self):
        """Test case for get_zone_spaces

        Retrieve all spaces of a zone  # noqa: E501
        """
        pass

    def test_get_zones(self):
        """Test case for get_zones

        Retrieve zones of a model  # noqa: E501
        """
        pass

    def test_link_documents_of_element(self):
        """Test case for link_documents_of_element

        Link one or many documents to an element  # noqa: E501
        """
        pass

    def test_list_classification_element_relations(self):
        """Test case for list_classification_element_relations

        List all associations between classifications and elements  # noqa: E501
        """
        pass

    def test_merge_ifcs(self):
        """Test case for merge_ifcs

        Merge IFC files  # noqa: E501
        """
        pass

    def test_optimize_ifc(self):
        """Test case for optimize_ifc

        Optimize the IFC  # noqa: E501
        """
        pass

    def test_remove_all_element_property_set(self):
        """Test case for remove_all_element_property_set

        Remove all property sets from element  # noqa: E501
        """
        pass

    def test_remove_classification_of_element(self):
        """Test case for remove_classification_of_element

        Remove a classification from an element  # noqa: E501
        """
        pass

    def test_remove_document_of_element(self):
        """Test case for remove_document_of_element

        Remove a documents from an element  # noqa: E501
        """
        pass

    def test_remove_element_property_set(self):
        """Test case for remove_element_property_set

        Remove a PropertySet from an element  # noqa: E501
        """
        pass

    def test_remove_element_property_set_property(self):
        """Test case for remove_element_property_set_property

        Remove a property from a PropertySet  # noqa: E501
        """
        pass

    def test_remove_element_property_set_property_definition(self):
        """Test case for remove_element_property_set_property_definition

        Delete a Definition to a Property  # noqa: E501
        """
        pass

    def test_remove_element_property_set_property_definition_unit(self):
        """Test case for remove_element_property_set_property_definition_unit

        Remove a Unit from a Definition  # noqa: E501
        """
        pass

    def test_remove_elements_from_classification(self):
        """Test case for remove_elements_from_classification

        Remove the classification from all elements  # noqa: E501
        """
        pass

    def test_reprocess_model(self):
        """Test case for reprocess_model

        Reprocess Model file  # noqa: E501
        """
        pass

    def test_update_access_token(self):
        """Test case for update_access_token

        Update some fields of a token  # noqa: E501
        """
        pass

    def test_update_building(self):
        """Test case for update_building

        Update some fields of a building  # noqa: E501
        """
        pass

    def test_update_building_plan_positioning(self):
        """Test case for update_building_plan_positioning

        Update the postioning of the plan in the building  # noqa: E501
        """
        pass

    def test_update_element(self):
        """Test case for update_element

        Update some fields of an element  # noqa: E501
        """
        pass

    def test_update_element_property_set_property(self):
        """Test case for update_element_property_set_property

        Update a property from an element  # noqa: E501
        """
        pass

    def test_update_layer(self):
        """Test case for update_layer

        Update some fields of a layer  # noqa: E501
        """
        pass

    def test_update_model(self):
        """Test case for update_model

        Update some fields of a model  # noqa: E501
        """
        pass

    def test_update_model_files(self):
        """Test case for update_model_files

        Update models file (gltf, svg, structure, etc)  # noqa: E501
        """
        pass

    def test_update_model_property(self):
        """Test case for update_model_property

        Update some fields of a Property  # noqa: E501
        """
        pass

    def test_update_model_property_definition(self):
        """Test case for update_model_property_definition

        Update some fields of many PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_update_model_unit(self):
        """Test case for update_model_unit

        Update some fields of a Unit of a model  # noqa: E501
        """
        pass

    def test_update_order_building_plan(self):
        """Test case for update_order_building_plan

        Update order of all plan of a building  # noqa: E501
        """
        pass

    def test_update_order_storey_plan(self):
        """Test case for update_order_storey_plan

        Update order of all plan of a storey  # noqa: E501
        """
        pass

    def test_update_order_storeys(self):
        """Test case for update_order_storeys

        Update order of all storey of a model  # noqa: E501
        """
        pass

    def test_update_processor_handler(self):
        """Test case for update_processor_handler

        Update the status of a processor handler  # noqa: E501
        """
        pass

    def test_update_property_set(self):
        """Test case for update_property_set

        Update some fields of a PropertySet  # noqa: E501
        """
        pass

    def test_update_space(self):
        """Test case for update_space

        Update some fields of a space  # noqa: E501
        """
        pass

    def test_update_storey(self):
        """Test case for update_storey

        Update some fields of a storey  # noqa: E501
        """
        pass

    def test_update_storey_plan_positioning(self):
        """Test case for update_storey_plan_positioning

        Update the postioning of the plan in the storey  # noqa: E501
        """
        pass

    def test_update_system(self):
        """Test case for update_system

        Update some fields of a system  # noqa: E501
        """
        pass

    def test_update_zone(self):
        """Test case for update_zone

        Update some fields of a zone  # noqa: E501
        """
        pass

    def test_update_zone_space(self):
        """Test case for update_zone_space

        Update some fields of a space  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.sso_api import SsoApi  # noqa: E501


class TestSsoApi(unittest.TestCase):
    """SsoApi unit test stubs"""

    def setUp(self):
        self.api = SsoApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_invitation(self):
        """Test case for accept_invitation

        Accept an invitation  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete user from BIMData  # noqa: E501
        """
        pass

    def test_deny_invitation(self):
        """Test case for deny_invitation

        Deny an invitation  # noqa: E501
        """
        pass

    def test_get_invitation(self):
        """Test case for get_invitation

        Retrieve an invitation  # noqa: E501
        """
        pass

    def test_get_invitations(self):
        """Test case for get_invitations

        Retrieve all invitations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.clipping_plane import ClippingPlane
from bimdata_api_client.model.components_parent import ComponentsParent
from bimdata_api_client.model.line import Line
from bimdata_api_client.model.orthogonal_camera import OrthogonalCamera
from bimdata_api_client.model.perspective_camera import PerspectiveCamera
from bimdata_api_client.model.pin import Pin
from bimdata_api_client.model.snapshot import Snapshot
globals()['ClippingPlane'] = ClippingPlane
globals()['ComponentsParent'] = ComponentsParent
globals()['Line'] = Line
globals()['OrthogonalCamera'] = OrthogonalCamera
globals()['PerspectiveCamera'] = PerspectiveCamera
globals()['Pin'] = Pin
globals()['Snapshot'] = Snapshot
from bimdata_api_client.model.viewpoint import Viewpoint


class TestViewpoint(unittest.TestCase):
    """Viewpoint unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testViewpoint(self):
        """Test Viewpoint"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Viewpoint()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from bimdata_api_client.api_client import ApiClient, Endpoint as _Endpoint
from bimdata_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from bimdata_api_client.model.patched_web_hook_request import PatchedWebHookRequest
from bimdata_api_client.model.web_hook import WebHook
from bimdata_api_client.model.web_hook_request import WebHookRequest


class WebhookApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_web_hook_endpoint = _Endpoint(
            settings={
                'response_type': (WebHook,),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/cloud/{cloud_pk}/webhook',
                'operation_id': 'create_web_hook',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cloud_pk',
                    'web_hook_request',
                ],
                'required': [
                    'cloud_pk',
                    'web_hook_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cloud_pk':
                        (int,),
                    'web_hook_request':
                        (WebHookRequest,),
                },
                'attribute_map': {
                    'cloud_pk': 'cloud_pk',
                },
                'location_map': {
                    'cloud_pk': 'path',
                    'web_hook_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )
        self.delete_web_hook_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/cloud/{cloud_pk}/webhook/{id}',
                'operation_id': 'delete_web_hook',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'cloud_pk',
                    'id',
                ],
                'required': [
                    'cloud_pk',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cloud_pk':
                        (int,),
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'cloud_pk': 'cloud_pk',
                    'id': 'id',
                },
                'location_map': {
                    'cloud_pk': 'path',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_web_hook_endpoint = _Endpoint(
            settings={
                'response_type': (WebHook,),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/cloud/{cloud_pk}/webhook/{id}',
                'operation_id': 'get_web_hook',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cloud_pk',
                    'id',
                ],
                'required': [
                    'cloud_pk',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cloud_pk':
                        (int,),
                    'id':
                        (int,),
                },
                'attribute_map': {
                    'cloud_pk': 'cloud_pk',
                    'id': 'id',
                },
                'location_map': {
                    'cloud_pk': 'path',
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_web_hooks_endpoint = _Endpoint(
            settings={
                'response_type': ([WebHook],),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/cloud/{cloud_pk}/webhook',
                'operation_id': 'get_web_hooks',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'cloud_pk',
                ],
                'required': [
                    'cloud_pk',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cloud_pk':
                        (int,),
                },
                'attribute_map': {
                    'cloud_pk': 'cloud_pk',
                },
                'location_map': {
                    'cloud_pk': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.ping_web_hook_endpoint = _Endpoint(
            settings={
                'response_type': (WebHook,),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/cloud/{cloud_pk}/webhook/{id}/ping',
                'operation_id': 'ping_web_hook',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'cloud_pk',
                    'id',
                    'web_hook_request',
                ],
                'required': [
                    'cloud_pk',
                    'id',
                    'web_hook_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cloud_pk':
                        (int,),
                    'id':
                        (int,),
                    'web_hook_request':
                        (WebHookRequest,),
                },
                'attribute_map': {
                    'cloud_pk': 'cloud_pk',
                    'id': 'id',
                },
                'location_map': {
                    'cloud_pk': 'path',
                    'id': 'path',
                    'web_hook_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )
        self.update_web_hook_endpoint = _Endpoint(
            settings={
                'response_type': (WebHook,),
                'auth': [
                    'ApiKey',
                    'BIMData_Connect',
                    'BIMData_Connect',
                    'Bearer'
                ],
                'endpoint_path': '/cloud/{cloud_pk}/webhook/{id}',
                'operation_id': 'update_web_hook',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'cloud_pk',
                    'id',
                    'patched_web_hook_request',
                ],
                'required': [
                    'cloud_pk',
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'cloud_pk':
                        (int,),
                    'id':
                        (int,),
                    'patched_web_hook_request':
                        (PatchedWebHookRequest,),
                },
                'attribute_map': {
                    'cloud_pk': 'cloud_pk',
                    'id': 'id',
                },
                'location_map': {
                    'cloud_pk': 'path',
                    'id': 'path',
                    'patched_web_hook_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json',
                    'application/x-www-form-urlencoded',
                    'multipart/form-data'
                ]
            },
            api_client=api_client
        )

    def create_web_hook(
        self,
        cloud_pk,
        web_hook_request,
        **kwargs
    ):
        """Create a new Webhook  # noqa: E501

        Create a new Webhook  Required scopes: webhook:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_web_hook(cloud_pk, web_hook_request, async_req=True)
        >>> result = thread.get()

        Args:
            cloud_pk (int):
            web_hook_request (WebHookRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            WebHook
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['cloud_pk'] = \
            cloud_pk
        kwargs['web_hook_request'] = \
            web_hook_request
        return self.create_web_hook_endpoint.call_with_http_info(**kwargs)

    def delete_web_hook(
        self,
        cloud_pk,
        id,
        **kwargs
    ):
        """Delete a webhook  # noqa: E501

        Delete a webhook  Required scopes: webhook:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_web_hook(cloud_pk, id, async_req=True)
        >>> result = thread.get()

        Args:
            cloud_pk (int):
            id (int): A unique integer value identifying this web hook.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['cloud_pk'] = \
            cloud_pk
        kwargs['id'] = \
            id
        return self.delete_web_hook_endpoint.call_with_http_info(**kwargs)

    def get_web_hook(
        self,
        cloud_pk,
        id,
        **kwargs
    ):
        """Retrieve one configured webhook  # noqa: E501

        Retrieve one configured webhook  Required scopes: webhook:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_web_hook(cloud_pk, id, async_req=True)
        >>> result = thread.get()

        Args:
            cloud_pk (int):
            id (int): A unique integer value identifying this web hook.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            WebHook
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['cloud_pk'] = \
            cloud_pk
        kwargs['id'] = \
            id
        return self.get_web_hook_endpoint.call_with_http_info(**kwargs)

    def get_web_hooks(
        self,
        cloud_pk,
        **kwargs
    ):
        """Retrieve all configured webhooks  # noqa: E501

        Retrieve all configured webhooks  Required scopes: webhook:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_web_hooks(cloud_pk, async_req=True)
        >>> result = thread.get()

        Args:
            cloud_pk (int):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [WebHook]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['cloud_pk'] = \
            cloud_pk
        return self.get_web_hooks_endpoint.call_with_http_info(**kwargs)

    def ping_web_hook(
        self,
        cloud_pk,
        id,
        web_hook_request,
        **kwargs
    ):
        """Test a webhook  # noqa: E501

        Trigger a Ping Event sending {\"ok\": true} to the webhook URL. Useful to test your app  Required scopes: webhook:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.ping_web_hook(cloud_pk, id, web_hook_request, async_req=True)
        >>> result = thread.get()

        Args:
            cloud_pk (int):
            id (int): A unique integer value identifying this web hook.
            web_hook_request (WebHookRequest):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            WebHook
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['cloud_pk'] = \
            cloud_pk
        kwargs['id'] = \
            id
        kwargs['web_hook_request'] = \
            web_hook_request
        return self.ping_web_hook_endpoint.call_with_http_info(**kwargs)

    def update_web_hook(
        self,
        cloud_pk,
        id,
        **kwargs
    ):
        """Update some field of a webhook  # noqa: E501

        Update some field of a webhook  Required scopes: webhook:manage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_web_hook(cloud_pk, id, async_req=True)
        >>> result = thread.get()

        Args:
            cloud_pk (int):
            id (int): A unique integer value identifying this web hook.

        Keyword Args:
            patched_web_hook_request (PatchedWebHookRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            WebHook
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['cloud_pk'] = \
            cloud_pk
        kwargs['id'] = \
            id
        return self.update_web_hook_endpoint.call_with_http_info(**kwargs)




"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import bimdata_api_client
from bimdata_api_client.model.check_plan import CheckPlan
from bimdata_api_client.model.checker_result import CheckerResult
from bimdata_api_client.model.model import Model
from bimdata_api_client.model.user import User
globals()['CheckPlan'] = CheckPlan
globals()['CheckerResult'] = CheckerResult
globals()['Model'] = Model
globals()['User'] = User
from bimdata_api_client.model.ifc_checker import IfcChecker


class TestIfcChecker(unittest.TestCase):
    """IfcChecker unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testIfcChecker(self):
        """Test IfcChecker"""
        # FIXME: construct object with mandatory attributes with example values
        # model = IfcChecker()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    BIMData API

    BIMData API is a tool to interact with your models stored on BIMData’s servers.     Through the API, you can manage your projects, the clouds, upload your IFC files and manage them through endpoints.  # noqa: E501

    The version of the OpenAPI document: v1 (v1)
    Contact: support@bimdata.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import bimdata_api_client
from bimdata_api_client.api.ifc_api import IfcApi  # noqa: E501


class TestIfcApi(unittest.TestCase):
    """IfcApi unit test stubs"""

    def setUp(self):
        self.api = IfcApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ifc_errors_deprecated(self):
        """Test case for add_ifc_errors_deprecated

        Add errors to model  # noqa: E501
        """
        pass

    def test_bulk_delete_ifc_classifications_deprecated(self):
        """Test case for bulk_delete_ifc_classifications_deprecated

        Remove all classifications from model's elements  # noqa: E501
        """
        pass

    def test_bulk_delete_ifc_properties_deprecated(self):
        """Test case for bulk_delete_ifc_properties_deprecated

        Delete many Property of a model  # noqa: E501
        """
        pass

    def test_bulk_delete_ifc_property_definitions_deprecated(self):
        """Test case for bulk_delete_ifc_property_definitions_deprecated

        Delete many PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_bulk_delete_ifc_units_deprecated(self):
        """Test case for bulk_delete_ifc_units_deprecated

        Delete many Units of a model  # noqa: E501
        """
        pass

    def test_bulk_delete_property_set_deprecated(self):
        """Test case for bulk_delete_property_set_deprecated

        Delete many PropertySet of a model  # noqa: E501
        """
        pass

    def test_bulk_full_update_elements_deprecated(self):
        """Test case for bulk_full_update_elements_deprecated

        Update many elements at once (only changing fields may be defined)  # noqa: E501
        """
        pass

    def test_bulk_full_update_ifc_property_deprecated(self):
        """Test case for bulk_full_update_ifc_property_deprecated

        Update some fields of many properties of a model  # noqa: E501
        """
        pass

    def test_bulk_remove_classifications_of_element_deprecated(self):
        """Test case for bulk_remove_classifications_of_element_deprecated

        Remove many classifications from an element  # noqa: E501
        """
        pass

    def test_bulk_remove_documents_of_element_deprecated(self):
        """Test case for bulk_remove_documents_of_element_deprecated

        Remove many documents from an element  # noqa: E501
        """
        pass

    def test_bulk_remove_elements_from_classification_deprecated(self):
        """Test case for bulk_remove_elements_from_classification_deprecated

        Remove the classifications from all elements  # noqa: E501
        """
        pass

    def test_bulk_update_elements_deprecated(self):
        """Test case for bulk_update_elements_deprecated

        Update many elements at once (all field must be defined)  # noqa: E501
        """
        pass

    def test_bulk_update_ifc_property_deprecated(self):
        """Test case for bulk_update_ifc_property_deprecated

        Update all fields of many properties of a model  # noqa: E501
        """
        pass

    def test_create_access_token_deprecated(self):
        """Test case for create_access_token_deprecated

        Create a token for this model  # noqa: E501
        """
        pass

    def test_create_building_deprecated(self):
        """Test case for create_building_deprecated

        Create a building of a model  # noqa: E501
        """
        pass

    def test_create_building_plan_deprecated(self):
        """Test case for create_building_plan_deprecated

        Create a relation between a 2d model and a building  # noqa: E501
        """
        pass

    def test_create_checker_deprecated(self):
        """Test case for create_checker_deprecated

        Create a checker to a model  # noqa: E501
        """
        pass

    def test_create_checker_result_deprecated(self):
        """Test case for create_checker_result_deprecated

        Create a CheckerResult  # noqa: E501
        """
        pass

    def test_create_classification_element_relations_deprecated(self):
        """Test case for create_classification_element_relations_deprecated

        Create association between existing classification and existing element  # noqa: E501
        """
        pass

    def test_create_classifications_of_element_deprecated(self):
        """Test case for create_classifications_of_element_deprecated

        Create one or many classifications to an element  # noqa: E501
        """
        pass

    def test_create_element_deprecated(self):
        """Test case for create_element_deprecated

        Create an element in the model  # noqa: E501
        """
        pass

    def test_create_element_property_set_deprecated(self):
        """Test case for create_element_property_set_deprecated

        Create a PropertySets to an element  # noqa: E501
        """
        pass

    def test_create_element_property_set_property_definition_deprecated(self):
        """Test case for create_element_property_set_property_definition_deprecated

        Create a Definition to a Property  # noqa: E501
        """
        pass

    def test_create_element_property_set_property_definition_unit_deprecated(self):
        """Test case for create_element_property_set_property_definition_unit_deprecated

        Create a Unit to a Definition  # noqa: E501
        """
        pass

    def test_create_element_property_set_property_deprecated(self):
        """Test case for create_element_property_set_property_deprecated

        Create a property to a PropertySet  # noqa: E501
        """
        pass

    def test_create_ifc_deprecated(self):
        """Test case for create_ifc_deprecated

        Make a PDF or Image file a Model  # noqa: E501
        """
        pass

    def test_create_ifc_property_definition_deprecated(self):
        """Test case for create_ifc_property_definition_deprecated

        Create a PropertyDefinition on the model  # noqa: E501
        """
        pass

    def test_create_ifc_unit_deprecated(self):
        """Test case for create_ifc_unit_deprecated

        Create a Unit on a model  # noqa: E501
        """
        pass

    def test_create_layer_deprecated(self):
        """Test case for create_layer_deprecated

        Create a layer in the model  # noqa: E501
        """
        pass

    def test_create_meta_building_deprecated(self):
        """Test case for create_meta_building_deprecated

        Create an empty 3D Model  # noqa: E501
        """
        pass

    def test_create_property_set_deprecated(self):
        """Test case for create_property_set_deprecated

        Create one or many PropertySet  # noqa: E501
        """
        pass

    def test_create_property_set_element_relations_deprecated(self):
        """Test case for create_property_set_element_relations_deprecated

        Create association between PropertySet and element  # noqa: E501
        """
        pass

    def test_create_raw_elements_deprecated(self):
        """Test case for create_raw_elements_deprecated

        Create elements in an optimized format  # noqa: E501
        """
        pass

    def test_create_space_deprecated(self):
        """Test case for create_space_deprecated

        Create a space in the model  # noqa: E501
        """
        pass

    def test_create_storey_deprecated(self):
        """Test case for create_storey_deprecated

        Create a storey of a model  # noqa: E501
        """
        pass

    def test_create_storey_plan_deprecated(self):
        """Test case for create_storey_plan_deprecated

        Create a relation between a 2d model and a storey  # noqa: E501
        """
        pass

    def test_create_system_deprecated(self):
        """Test case for create_system_deprecated

        Create a system in the model  # noqa: E501
        """
        pass

    def test_create_tileset_deprecated(self):
        """Test case for create_tileset_deprecated

        Create the tileset of the model and upload all files  # noqa: E501
        """
        pass

    def test_create_zone_deprecated(self):
        """Test case for create_zone_deprecated

        Create a zone in the model  # noqa: E501
        """
        pass

    def test_create_zone_space_deprecated(self):
        """Test case for create_zone_space_deprecated

        Create a space in a zone  # noqa: E501
        """
        pass

    def test_delete_access_token_deprecated(self):
        """Test case for delete_access_token_deprecated

        Delete a token  # noqa: E501
        """
        pass

    def test_delete_building_deprecated(self):
        """Test case for delete_building_deprecated

        Delete a building of a model  # noqa: E501
        """
        pass

    def test_delete_building_plan_deprecated(self):
        """Test case for delete_building_plan_deprecated

        Delete the relation between a 2d model and a building  # noqa: E501
        """
        pass

    def test_delete_checker_deprecated(self):
        """Test case for delete_checker_deprecated

        Delete a checker of a model  # noqa: E501
        """
        pass

    def test_delete_checker_result_deprecated(self):
        """Test case for delete_checker_result_deprecated

        Delete a CheckerResult  # noqa: E501
        """
        pass

    def test_delete_element_deprecated(self):
        """Test case for delete_element_deprecated

        Delete an element of a model  # noqa: E501
        """
        pass

    def test_delete_ifc_deprecated(self):
        """Test case for delete_ifc_deprecated

        Delete a model  # noqa: E501
        """
        pass

    def test_delete_ifc_property_definition_deprecated(self):
        """Test case for delete_ifc_property_definition_deprecated

        Delete a PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_delete_ifc_property_deprecated(self):
        """Test case for delete_ifc_property_deprecated

        Delete a Property of a model  # noqa: E501
        """
        pass

    def test_delete_ifc_unit_deprecated(self):
        """Test case for delete_ifc_unit_deprecated

        Delete a Unit of a model  # noqa: E501
        """
        pass

    def test_delete_ifc_without_doc_deprecated(self):
        """Test case for delete_ifc_without_doc_deprecated

        Delete the Model without deleting the related document  # noqa: E501
        """
        pass

    def test_delete_layer_deprecated(self):
        """Test case for delete_layer_deprecated

        Delete a layer of a model  # noqa: E501
        """
        pass

    def test_delete_property_set_deprecated(self):
        """Test case for delete_property_set_deprecated

        Delete a PropertySet of a model  # noqa: E501
        """
        pass

    def test_delete_space_deprecated(self):
        """Test case for delete_space_deprecated

        Delete a space  # noqa: E501
        """
        pass

    def test_delete_storey_deprecated(self):
        """Test case for delete_storey_deprecated

        Delete a storey of a model  # noqa: E501
        """
        pass

    def test_delete_storey_plan_deprecated(self):
        """Test case for delete_storey_plan_deprecated

        Delete the relation between a 2d model and a storey  # noqa: E501
        """
        pass

    def test_delete_system_deprecated(self):
        """Test case for delete_system_deprecated

        Delete a system of a model  # noqa: E501
        """
        pass

    def test_delete_zone_deprecated(self):
        """Test case for delete_zone_deprecated

        Delete a zone of a model  # noqa: E501
        """
        pass

    def test_delete_zone_space_deprecated(self):
        """Test case for delete_zone_space_deprecated

        Delete a space of a zone  # noqa: E501
        """
        pass

    def test_export_ifc_deprecated(self):
        """Test case for export_ifc_deprecated

        Export IFC  # noqa: E501
        """
        pass

    def test_full_update_element_deprecated(self):
        """Test case for full_update_element_deprecated

        Update all fields of an element  # noqa: E501
        """
        pass

    def test_get_access_token_deprecated(self):
        """Test case for get_access_token_deprecated

        Retrieve one token created for this model  # noqa: E501
        """
        pass

    def test_get_access_tokens_deprecated(self):
        """Test case for get_access_tokens_deprecated

        Retrieve all tokens created for this model  # noqa: E501
        """
        pass

    def test_get_building_deprecated(self):
        """Test case for get_building_deprecated

        Retrieve a building of a model  # noqa: E501
        """
        pass

    def test_get_building_plan_positioning_deprecated(self):
        """Test case for get_building_plan_positioning_deprecated

        Retrieve the postioning of the plan in the building  # noqa: E501
        """
        pass

    def test_get_buildings_deprecated(self):
        """Test case for get_buildings_deprecated

        Retrieve all buildings of a model  # noqa: E501
        """
        pass

    def test_get_checker_deprecated(self):
        """Test case for get_checker_deprecated

        Retrieve a checker of a model  # noqa: E501
        """
        pass

    def test_get_checker_result_deprecated(self):
        """Test case for get_checker_result_deprecated

        Retrieve one CheckerResult  # noqa: E501
        """
        pass

    def test_get_checker_results_deprecated(self):
        """Test case for get_checker_results_deprecated

        Retrieve all CheckerResults  # noqa: E501
        """
        pass

    def test_get_checkers_deprecated(self):
        """Test case for get_checkers_deprecated

        Retrieve all checkers of a model  # noqa: E501
        """
        pass

    def test_get_classifications_of_element_deprecated(self):
        """Test case for get_classifications_of_element_deprecated

        Retrieve all classifications of an element  # noqa: E501
        """
        pass

    def test_get_documents_of_element_deprecated(self):
        """Test case for get_documents_of_element_deprecated

        Retrieve all documents of an element  # noqa: E501
        """
        pass

    def test_get_element_deprecated(self):
        """Test case for get_element_deprecated

        Retrieve an element of a model  # noqa: E501
        """
        pass

    def test_get_element_linked_documents_deprecated(self):
        """Test case for get_element_linked_documents_deprecated

        Retrieve all documents linked to any element  # noqa: E501
        """
        pass

    def test_get_element_property_set_deprecated(self):
        """Test case for get_element_property_set_deprecated

        Retrieve a PropertySet of an element  # noqa: E501
        """
        pass

    def test_get_element_property_set_properties_deprecated(self):
        """Test case for get_element_property_set_properties_deprecated

        Retrieve all Properties of a PropertySet  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definition_deprecated(self):
        """Test case for get_element_property_set_property_definition_deprecated

        Retrieve a Definition of a Property  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definition_unit_deprecated(self):
        """Test case for get_element_property_set_property_definition_unit_deprecated

        Retrieve a Unit of a Definition  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definition_units_deprecated(self):
        """Test case for get_element_property_set_property_definition_units_deprecated

        Retrieve all Units of a Definition  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_definitions_deprecated(self):
        """Test case for get_element_property_set_property_definitions_deprecated

        Retrieve all Definitions of a PropertySet  # noqa: E501
        """
        pass

    def test_get_element_property_set_property_deprecated(self):
        """Test case for get_element_property_set_property_deprecated

        Retrieve a Property of a PropertySet  # noqa: E501
        """
        pass

    def test_get_element_property_sets_deprecated(self):
        """Test case for get_element_property_sets_deprecated

        Retrieve all PropertySets of an element  # noqa: E501
        """
        pass

    def test_get_elements_deprecated(self):
        """Test case for get_elements_deprecated

        Retrieve all elements of a model  # noqa: E501
        """
        pass

    def test_get_elements_from_classification_deprecated(self):
        """Test case for get_elements_from_classification_deprecated

        Retrieve all elements with the classification  # noqa: E501
        """
        pass

    def test_get_ifc_classifications_deprecated(self):
        """Test case for get_ifc_classifications_deprecated

        Retrieve all classifications in a model  # noqa: E501
        """
        pass

    def test_get_ifc_deprecated(self):
        """Test case for get_ifc_deprecated

        Retrieve one model  # noqa: E501
        """
        pass

    def test_get_ifc_material_deprecated(self):
        """Test case for get_ifc_material_deprecated

        Retrieve a material of a model  # noqa: E501
        """
        pass

    def test_get_ifc_materials_deprecated(self):
        """Test case for get_ifc_materials_deprecated

        Retrieve all materials of a model  # noqa: E501
        """
        pass

    def test_get_ifc_properties_deprecated(self):
        """Test case for get_ifc_properties_deprecated

        Retrieve all Properties of a model  # noqa: E501
        """
        pass

    def test_get_ifc_property_definition_deprecated(self):
        """Test case for get_ifc_property_definition_deprecated

        Retrieve a PropertyDefinition of a model  # noqa: E501
        """
        pass

    def test_get_ifc_property_definitions_deprecated(self):
        """Test case for get_ifc_property_definitions_deprecated

        Retrieve all PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_get_ifc_property_deprecated(self):
        """Test case for get_ifc_property_deprecated

        Retrieve a Property of a model  # noqa: E501
        """
        pass

    def test_get_ifc_unit_deprecated(self):
        """Test case for get_ifc_unit_deprecated

        Retrieve a Unit of a model  # noqa: E501
        """
        pass

    def test_get_ifc_units_deprecated(self):
        """Test case for get_ifc_units_deprecated

        Retrieve all Units of a model  # noqa: E501
        """
        pass

    def test_get_ifcs_deprecated(self):
        """Test case for get_ifcs_deprecated

        Retrieve all models  # noqa: E501
        """
        pass

    def test_get_layer_deprecated(self):
        """Test case for get_layer_deprecated

        Retrieve a layer of a model  # noqa: E501
        """
        pass

    def test_get_layers_deprecated(self):
        """Test case for get_layers_deprecated

        Retrieve all layers of a model  # noqa: E501
        """
        pass

    def test_get_material_deprecated(self):
        """Test case for get_material_deprecated

        Retrieve a material of a model  # noqa: E501
        """
        pass

    def test_get_materials_deprecated(self):
        """Test case for get_materials_deprecated

        Retrieve all materials of a model  # noqa: E501
        """
        pass

    def test_get_processor_handler_deprecated(self):
        """Test case for get_processor_handler_deprecated

        Retrieve a processor handler  # noqa: E501
        """
        pass

    def test_get_processor_handlers_deprecated(self):
        """Test case for get_processor_handlers_deprecated

        Get all processor handlers  # noqa: E501
        """
        pass

    def test_get_property_set_deprecated(self):
        """Test case for get_property_set_deprecated

        Retrieve a PropertySet of a model  # noqa: E501
        """
        pass

    def test_get_property_sets_deprecated(self):
        """Test case for get_property_sets_deprecated

        Retrieve all PropertySets of a model  # noqa: E501
        """
        pass

    def test_get_raw_elements_deprecated(self):
        """Test case for get_raw_elements_deprecated

        Retrieve all elements in a optimized format  # noqa: E501
        """
        pass

    def test_get_simple_element_deprecated(self):
        """Test case for get_simple_element_deprecated

        Retrieve an element of a model with a simple value representation  # noqa: E501
        """
        pass

    def test_get_simple_elements_deprecated(self):
        """Test case for get_simple_elements_deprecated

        Retrieve all elements of a model with a simple value representation  # noqa: E501
        """
        pass

    def test_get_space_deprecated(self):
        """Test case for get_space_deprecated

        Retrieve one space of the model  # noqa: E501
        """
        pass

    def test_get_spaces_deprecated(self):
        """Test case for get_spaces_deprecated

        Retrieve all spaces of the model  # noqa: E501
        """
        pass

    def test_get_storey_deprecated(self):
        """Test case for get_storey_deprecated

        Retrieve a storey of a model  # noqa: E501
        """
        pass

    def test_get_storey_plan_positioning_deprecated(self):
        """Test case for get_storey_plan_positioning_deprecated

        Retrieve the postioning of the plan in the storey  # noqa: E501
        """
        pass

    def test_get_storeys_deprecated(self):
        """Test case for get_storeys_deprecated

        Retrieve all storeys of a model  # noqa: E501
        """
        pass

    def test_get_system_deprecated(self):
        """Test case for get_system_deprecated

        Retrieve a system of a model  # noqa: E501
        """
        pass

    def test_get_systems_deprecated(self):
        """Test case for get_systems_deprecated

        Retrieve all systems of a model  # noqa: E501
        """
        pass

    def test_get_tileset_deprecated(self):
        """Test case for get_tileset_deprecated

        Retrieve the tileset of the model  # noqa: E501
        """
        pass

    def test_get_zone_deprecated(self):
        """Test case for get_zone_deprecated

        Retrieve one zone of a model  # noqa: E501
        """
        pass

    def test_get_zone_space_deprecated(self):
        """Test case for get_zone_space_deprecated

        Retrieve one space of a zone  # noqa: E501
        """
        pass

    def test_get_zone_spaces_deprecated(self):
        """Test case for get_zone_spaces_deprecated

        Retrieve all spaces of a zone  # noqa: E501
        """
        pass

    def test_get_zones_deprecated(self):
        """Test case for get_zones_deprecated

        Retrieve zones of a model  # noqa: E501
        """
        pass

    def test_launch_new_check_deprecated(self):
        """Test case for launch_new_check_deprecated

        Launch a new check on the model  # noqa: E501
        """
        pass

    def test_link_documents_of_element_deprecated(self):
        """Test case for link_documents_of_element_deprecated

        Link one or many documents to an element  # noqa: E501
        """
        pass

    def test_list_classification_element_relations_deprecated(self):
        """Test case for list_classification_element_relations_deprecated

        List all associations between classifications and elements  # noqa: E501
        """
        pass

    def test_merge_ifcs_deprecated(self):
        """Test case for merge_ifcs_deprecated

        Merge IFC files  # noqa: E501
        """
        pass

    def test_optimize_ifc_deprecated(self):
        """Test case for optimize_ifc_deprecated

        Optimize the IFC  # noqa: E501
        """
        pass

    def test_remove_all_element_property_set_deprecated(self):
        """Test case for remove_all_element_property_set_deprecated

        Remove all property sets from element  # noqa: E501
        """
        pass

    def test_remove_classification_of_element_deprecated(self):
        """Test case for remove_classification_of_element_deprecated

        Remove a classification from an element  # noqa: E501
        """
        pass

    def test_remove_document_of_element_deprecated(self):
        """Test case for remove_document_of_element_deprecated

        Remove a documents from an element  # noqa: E501
        """
        pass

    def test_remove_element_property_set_deprecated(self):
        """Test case for remove_element_property_set_deprecated

        Remove a PropertySet from an element  # noqa: E501
        """
        pass

    def test_remove_element_property_set_property_definition_deprecated(self):
        """Test case for remove_element_property_set_property_definition_deprecated

        Delete a Definition to a Property  # noqa: E501
        """
        pass

    def test_remove_element_property_set_property_definition_unit_deprecated(self):
        """Test case for remove_element_property_set_property_definition_unit_deprecated

        Remove a Unit from a Definition  # noqa: E501
        """
        pass

    def test_remove_element_property_set_property_deprecated(self):
        """Test case for remove_element_property_set_property_deprecated

        Remove a property from a PropertySet  # noqa: E501
        """
        pass

    def test_remove_elements_from_classification_deprecated(self):
        """Test case for remove_elements_from_classification_deprecated

        Remove the classification from all elements  # noqa: E501
        """
        pass

    def test_reprocess_ifc_deprecated(self):
        """Test case for reprocess_ifc_deprecated

        Reprocess Model file  # noqa: E501
        """
        pass

    def test_update_access_token_deprecated(self):
        """Test case for update_access_token_deprecated

        Update some fields of a token  # noqa: E501
        """
        pass

    def test_update_building_deprecated(self):
        """Test case for update_building_deprecated

        Update some fields of a building  # noqa: E501
        """
        pass

    def test_update_building_plan_positioning_deprecated(self):
        """Test case for update_building_plan_positioning_deprecated

        Update the postioning of the plan in the building  # noqa: E501
        """
        pass

    def test_update_checker_deprecated(self):
        """Test case for update_checker_deprecated

        Update some fields of a checker of a model  # noqa: E501
        """
        pass

    def test_update_checker_result_deprecated(self):
        """Test case for update_checker_result_deprecated

        Update some fields of a CheckerResult  # noqa: E501
        """
        pass

    def test_update_element_deprecated(self):
        """Test case for update_element_deprecated

        Update some fields of an element  # noqa: E501
        """
        pass

    def test_update_element_property_set_property_deprecated(self):
        """Test case for update_element_property_set_property_deprecated

        Update a property from an element  # noqa: E501
        """
        pass

    def test_update_ifc_deprecated(self):
        """Test case for update_ifc_deprecated

        Update some fields of a model  # noqa: E501
        """
        pass

    def test_update_ifc_files_deprecated(self):
        """Test case for update_ifc_files_deprecated

        Update models file (gltf, svg, structure, etc)  # noqa: E501
        """
        pass

    def test_update_ifc_property_definition_deprecated(self):
        """Test case for update_ifc_property_definition_deprecated

        Update some fields of many PropertyDefinitions of a model  # noqa: E501
        """
        pass

    def test_update_ifc_property_deprecated(self):
        """Test case for update_ifc_property_deprecated

        Update some fields of a Property  # noqa: E501
        """
        pass

    def test_update_ifc_unit_deprecated(self):
        """Test case for update_ifc_unit_deprecated

        Update some fields of a Unit of a model  # noqa: E501
        """
        pass

    def test_update_layer_deprecated(self):
        """Test case for update_layer_deprecated

        Update some fields of a layer  # noqa: E501
        """
        pass

    def test_update_order_building_plan_deprecated(self):
        """Test case for update_order_building_plan_deprecated

        Update order of all plan of a building  # noqa: E501
        """
        pass

    def test_update_order_storey_plan_deprecated(self):
        """Test case for update_order_storey_plan_deprecated

        Update order of all plan of a storey  # noqa: E501
        """
        pass

    def test_update_order_storeys_deprecated(self):
        """Test case for update_order_storeys_deprecated

        Update order of all storey of a model  # noqa: E501
        """
        pass

    def test_update_processor_handler_deprecated(self):
        """Test case for update_processor_handler_deprecated

        Update the status of a processor handler  # noqa: E501
        """
        pass

    def test_update_property_set_deprecated(self):
        """Test case for update_property_set_deprecated

        Update some fields of a PropertySet  # noqa: E501
        """
        pass

    def test_update_space_deprecated(self):
        """Test case for update_space_deprecated

        Update some fields of a space  # noqa: E501
        """
        pass

    def test_update_storey_deprecated(self):
        """Test case for update_storey_deprecated

        Update some fields of a storey  # noqa: E501
        """
        pass

    def test_update_storey_plan_positioning_deprecated(self):
        """Test case for update_storey_plan_positioning_deprecated

        Update the postioning of the plan in the storey  # noqa: E501
        """
        pass

    def test_update_system_deprecated(self):
        """Test case for update_system_deprecated

        Update some fields of a system  # noqa: E501
        """
        pass

    def test_update_zone_deprecated(self):
        """Test case for update_zone_deprecated

        Update some fields of a zone  # noqa: E501
        """
        pass

    def test_update_zone_space_deprecated(self):
        """Test case for update_zone_space_deprecated

        Update some fields of a space  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
